@@ -145,8 +145,7 @@ Message::Private::Private (const Message::Private &other)
 
 Message::Private::~Private ()
 {
-	if ( fileTransfer )
-		delete fileTransfer;
+	delete fileTransfer;
 
 	delete body;
 }
@@ -295,9 +294,9 @@ QString Message::unescape( const QString &xml )
 
 		// Take the part between < and >, and extract the element name from that
 		int matchWidth = endPos - pos + 1;
-		QString match = data.mid( pos + 1, matchWidth - 2 ).simplified();
+		const QString match = data.mid( pos + 1, matchWidth - 2 ).simplified();
 		int elemEndPos = match.indexOf( ' ' );
-		QString elem = ( elemEndPos == -1 ? match.toLower() : match.left( elemEndPos ).toLower() );
+		const QString elem = ( elemEndPos == -1 ? match.toLower() : match.left( elemEndPos ).toLower() );
 		if ( elem == QLatin1String( "img" ) )
 		{
 			// Replace smileys with their original text'
@@ -413,6 +412,20 @@ static QString makeRegExp( const char *pattern )
 	return boundaryStart + QLatin1String(pattern) + boundaryEnd;
 }
 
+const QStringList Message::regexpPatterns()
+{
+        const QString name = QLatin1String( "[\\w\\+\\-=_\\.]+" );
+        const QString userAndPassword = QString( "(?:%1(?::%1)?\\@)" ).arg( name );
+        const QString urlChar = QLatin1String( "\\+\\-\\w\\./#@&;:=\\?~%_,\\!\\$\\*\\(\\)" );
+        const QString urlSection = QString( "[%1]+" ).arg( urlChar );
+        const QString domain = QLatin1String( "[\\-\\w_]+(?:\\.[\\-\\w_]+)+" );
+        QStringList patternList;
+        patternList << makeRegExp("\\w+://%1?\\w%2").arg( userAndPassword, urlSection )
+                    << makeRegExp("%1?www\\.%2%3").arg( userAndPassword, domain, urlSection )
+                    << makeRegExp("%1@%2").arg( name, domain );
+        return patternList;
+}
+
 QString Message::parseLinks( const QString &message, Qt::TextFormat format )
 {
 	if ( format & Qt::RichText )
