@@ -106,20 +106,6 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 	 */
 	setDontSync ( true );
 
-	// The myself contact is not in the roster on server, ignore this code
-	// because the myself MetaContact displayname become the latest 
-	// Jabber acccount jid.
-	if( metaContact() != Kopete::ContactList::self()->myself() )
-	{
-		// only update the alias if it is not empty
-		if ( !item.name().isEmpty () && item.name() != item.jid().bare() 
-			&& metaContact()->customDisplayName() != item.name () )
-		{
-			kDebug ( JABBER_DEBUG_GLOBAL ) << "setting display name of " << contactId () << " to " << item.name();
-			metaContact()->setDisplayName ( item.name () );
-		}
-	}
-
 	/*
 	 * Set the contact's subscription status
 	 */
@@ -206,6 +192,12 @@ void JabberBaseContact::updateContact ( const XMPP::RosterItem & item )
 			kDebug ( JABBER_DEBUG_GLOBAL ) << "Adding " << contactId() << " to group " << group->displayName ();
 			metaContact()->addToGroup ( group );
 		}
+
+		//Set nick name from roster
+		if ( ! item.name().isEmpty() )
+		{
+			setProperty ( protocol()->propNickName, item.name() );
+		}
 	}
 
 	/*
@@ -414,7 +406,11 @@ void JabberBaseContact::setPropertiesFromVCard ( const XMPP::VCard &vCard )
 	*/
 	if(inherits ( "JabberContact" ))
 	{
-		if ( !vCard.nickName().isEmpty () )
+		if ( !mRosterItem.name().isEmpty() )
+		{
+			setProperty ( protocol()->propNickName, mRosterItem.name() );
+		}
+		else if ( !vCard.nickName().isEmpty () )
 		{
 			setProperty ( protocol()->propNickName, vCard.nickName () );
 		}
