@@ -37,6 +37,8 @@ extern "C"
 #include "libyahoo.h"
 }
 
+using namespace KYahoo;
+
 LoginTask::LoginTask(Task* parent) : Task(parent)
 {
 	kDebug(YAHOO_RAW_DEBUG) ;
@@ -211,12 +213,13 @@ void LoginTask::sendAuthSixteenStage1(const QString& sn, const QString& seed)
 	kDebug(YAHOO_RAW_DEBUG) << "seed:" << seed;
 	m_stage1Data.clear();
 	/* construct a URL from the seed and request tokens */
-	QByteArray encodedUrl;
-	QString fullUrl = YahooTokenUrl.arg(sn, client()->password(), seed);
+	QString encodedPassword(QUrl::toPercentEncoding(client()->password()));
+	QString encodedUser(QUrl::toPercentEncoding(sn));
+	QString fullUrl = YahooTokenUrl.arg(encodedUser, encodedPassword, seed);
 	KUrl tokenUrl(fullUrl);
 	KIO::Job* job = KIO::get(tokenUrl, KIO::Reload, KIO::HideProgressInfo);
-	connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-	        this, SLOT(handleAuthSixteenStage1Data(KIO::Job*, const QByteArray&)));
+	connect(job, SIGNAL(data(KIO::Job*,QByteArray)),
+	        this, SLOT(handleAuthSixteenStage1Data(KIO::Job*,QByteArray)));
 	connect(job, SIGNAL(result(KJob*)),
 	        this, SLOT(handleAuthSixteenStage1Result(KJob*)));
 }
@@ -295,8 +298,8 @@ void LoginTask::sendAuthSixteenStage2(const QString& token)
 	QString fullUrl = YahooLoginUrl.arg(token);
 	KUrl loginUrl(fullUrl);
 	KIO::Job* job = KIO::get(loginUrl, KIO::Reload, KIO::HideProgressInfo);
-	connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-	        this, SLOT(handleAuthSixteenStage2Data(KIO::Job*, const QByteArray&)));
+	connect(job, SIGNAL(data(KIO::Job*,QByteArray)),
+	        this, SLOT(handleAuthSixteenStage2Data(KIO::Job*,QByteArray)));
 	connect(job, SIGNAL(result(KJob*)),
 	        this, SLOT(handleAuthSixteenStage2Result(KJob*)));
 }
