@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2007-2008 Urs Wolfer <uwolfer @ kde.org>
+** Copyright (C) 2007-2012 Urs Wolfer <uwolfer @ kde.org>
 **
 ** This file is part of KDE.
 **
@@ -57,7 +57,6 @@ VncView::VncView(QWidget *parent, const KUrl &url, KConfigGroup configGroup)
         m_repaint(false),
         m_quitFlag(false),
         m_firstPasswordTry(true),
-        m_authenticaionCanceled(false),
         m_dontSendClipboard(false),
         m_horizontalFactor(1.0),
         m_verticalFactor(1.0),
@@ -67,13 +66,12 @@ VncView::VncView(QWidget *parent, const KUrl &url, KConfigGroup configGroup)
     m_host = url.host();
     m_port = url.port();
 
-    connect(&vncThread, SIGNAL(imageUpdated(int, int, int, int)), this, SLOT(updateImage(int, int, int, int)), Qt::BlockingQueuedConnection);
-    connect(&vncThread, SIGNAL(gotCut(const QString&)), this, SLOT(setCut(const QString&)), Qt::BlockingQueuedConnection);
+    connect(&vncThread, SIGNAL(imageUpdated(int,int,int,int)), this, SLOT(updateImage(int,int,int,int)), Qt::BlockingQueuedConnection);
+    connect(&vncThread, SIGNAL(gotCut(QString)), this, SLOT(setCut(QString)), Qt::BlockingQueuedConnection);
     connect(&vncThread, SIGNAL(passwordRequest()), this, SLOT(requestPassword()), Qt::BlockingQueuedConnection);
     connect(&vncThread, SIGNAL(outputErrorMessage(QString)), this, SLOT(outputErrorMessage(QString)));
 
     m_clipboard = QApplication::clipboard();
-    connect(m_clipboard, SIGNAL(selectionChanged()), this, SLOT(clipboardSelectionChanged()));
     connect(m_clipboard, SIGNAL(dataChanged()), this, SLOT(clipboardDataChanged()));
     
 #ifndef QTONLY
@@ -157,24 +155,20 @@ void VncView::startQuitting()
 
     setStatus(Disconnecting);
 
+    m_quitFlag = true;
+
+    vncThread.stop();
+
     unpressModifiers();
 
     // Disconnect all signals so that we don't get any more callbacks from the client thread
-    bool imageUpdatedDisconnect = disconnect(&vncThread, SIGNAL(imageUpdated(int, int, int, int)), this, SLOT(updateImage(int, int, int, int)));
-    bool gotCutDisconnect = disconnect(&vncThread, SIGNAL(gotCut(const QString&)), this, SLOT(setCut(const QString&)));
+    bool imageUpdatedDisconnect = disconnect(&vncThread, SIGNAL(imageUpdated(int,int,int,int)), this, SLOT(updateImage(int,int,int,int)));
+    bool gotCutDisconnect = disconnect(&vncThread, SIGNAL(gotCut(QString)), this, SLOT(setCut(QString)));
     bool passwordRequestDisconnect = disconnect(&vncThread, SIGNAL(passwordRequest()), this, SLOT(requestPassword()));
     bool outputErrorMessageDisconnect = disconnect(&vncThread, SIGNAL(outputErrorMessage(QString)), this, SLOT(outputErrorMessage(QString)));
 
     kDebug(5011) << "Signals disconnected: imageUpdated: " << imageUpdatedDisconnect << "gotCut: " << gotCutDisconnect << "passwordRequest: " << passwordRequestDisconnect << "outputErrorMessage: " << outputErrorMessageDisconnect;
 
-    const bool connected = status() == RemoteView::Connected;
-
-    m_quitFlag = true;
-
-    if (connected) {
-        vncThread.stop();
-    }
-
     vncThread.quit();
 
     const bool quitSuccess = vncThread.wait(1000);
@@ -234,11 +228,6 @@ void VncView::requestPassword()
 {
     kDebug(5011) << "request password";
 
-    if (m_authenticaionCanceled) {
-        startQuitting();
-        return;
-    }
-
     setStatus(Authenticating);
 
 #ifndef QTONLY
@@ -254,8 +243,9 @@ void VncView::requestPassword()
     }
 #endif
 
-    if (!m_url.password().isNull()) {
+    if (m_firstPasswordTry && !m_url.password().isNull()) {
         vncThread.setPassword(m_url.password());
+        m_firstPasswordTry = false;
         return;
     }
 
@@ -269,7 +259,7 @@ void VncView::requestPassword()
     if (ok)
         vncThread.setPassword(password);
     else
-        m_authenticaionCanceled = true;
+        startQuitting();
 #else
     KPasswordDialog dialog(this);
     dialog.setPrompt(m_firstPasswordTry ? i18n("Access to the system requires a password.")
@@ -279,7 +269,7 @@ void VncView::requestPassword()
         vncThread.setPassword(dialog.password());
     } else {
         kDebug(5011) << "password dialog not accepted";
-        m_authenticaionCanceled = true;
+        startQuitting();
     }
 #endif
 }
@@ -422,7 +412,6 @@ void VncView::setCut(const QString &text)
 {
     m_dontSendClipboard = true;
     m_clipboard->setText(text, QClipboard::Clipboard);
-    m_clipboard->setText(text, QClipboard::Selection);
     m_dontSendClipboard = false;
 }
 
@@ -585,21 +574,6 @@ void VncView::unpressModifiers()
     m_mods.clear();
 }
 
-void VncView::clipboardSelectionChanged()
-{
-    kDebug(5011);
-
-    if (m_status != Connected)
-        return;
-
-    if (m_clipboard->ownsSelection() || m_dontSendClipboard)
-        return;
-
-    const QString text = m_clipboard->text(QClipboard::Selection);
-
-    vncThread.clientCut(text);
-}
-
 void VncView::clipboardDataChanged()
 {
     kDebug(5011);
